Method: DataObjects::SavePoint#close

Defined in:
lib/data_objects/transaction.rb

#closeObject

SavePoints can only occur in the context of a Transaction, thus they re-use TXN’s connection (which was acquired from the connection pool legitimately via DO::Connection.new). We no-op #close in SP because calling DO::Connection#close will release the connection back into the pool (before the top-level Transaction might be done with it).



80
81
82
# File 'lib/data_objects/transaction.rb', line 80

def close
    # no-op
end